{% extends 'base.html' %}

{% block content %}
<div class="form-group">
    <h2>Add new Mailbox:</h2>
    <form method="post">
        <div class="row mb-3">
            <label class="col-sm-2 col-form-label">First name</label>
            <div class="col-sm-10">
                <input class="form-control" type="text" name="firstname" placeholder="First Name" required>
            </div>
        </div>
        <div class="row mb-3">
            <label class="col-sm-2 col-form-label">Last name</label>
            <div class="col-sm-10">
                <input class="form-control" type="text" name="lastname" placeholder="Last Name" required>
            </div>
        </div>
        <div class="row mb-3">
            <label class="col-sm-2 col-form-label">Mailbox</label>
            <div class="col-sm-10">
                <input class="form-control" type="text" name="mailbox_name" placeholder="Mailbox@domain.com" required>
            </div>
        </div>
        <div class="row mb-3">
            <label class="col-sm-2 col-form-label">Role</label>
            <div class="col-sm-10">
                <input class="form-control" type="text" name="role" placeholder="Role" required>
            </div>
        </div>
        <div class="row">
            <input class="btn btn-lg btn-primary" type="submit" value="OK"></div>
    </form>
</div>
{% endblock %}