<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link rel="stylesheet" href="/static/bootstrap.min.css">
    <script src="/static/bootstrap.bundle.min.js"></script>
</head>
<body>
<nav class="navbar navbar-expand-lg navbar-dark bg-primary">
    <div class="container-fluid">

        <a class="navbar-brand" href="#"><img src="/static/logo.png" alt=""> CDR</a></div>
</nav>
<section class="h-100">
    <div class="container h-100">
        <div class="row justify-content-sm-center h-100">
            <div class="col-xxl-4 col-xl-5 col-lg-5 col-md-7 col-sm-9">
                <div class="card border-primary">
                    <div class="card-body p-5">
                        <h1 class="fs-4 card-title fw-bold mb-4">Login</h1>
                        <form method="post">
                            <div class="form-group">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="floatingInput" name="username" required>
                                    <label for="floatingInput">User name</label>
                                </div>
                                <div class="form-floating">
                                    <input type="password" class="form-control" id="floatingPassword" name="password"
                                           required>
                                    <label for="floatingPassword">Password</label>
                                </div>
                            </div>
                            <br>
                            <div class="row button">
                                <input class="btn btn-lg btn-primary" type="submit" value="Login">
                            </div>
                            <br>
                            <div style="color:red">{{error}}</div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
</section>
<div class="fixed-bottom bd-highlight bg-primary text-white">
    <p class="text-center">CDR project by Elad Kristal and Shahar Hazan</p>
</div>
</body>
</html>


