{% extends 'base.html' %}
{% block content %}
<div class="card">
    <div class="card-header">
        {{header}}
    </div>
    <div class="card-body">
        <h5 class="card-title">About Us</h5>
        <p class="card-text">The project created by Elad Kristal and Shahar Hazan for Achva collage.</p>
        <p class="card-text">This is an open source project using Python, Flask, MySQL and HMailServer. <br> you can
            find the source code for our project in our <a href="https://github.com/Mrkristal/CDR">Github.</a></p>
    </div>
    <div class="card-footer text-muted">
    </div>
</div>
{% endblock %}