{% extends 'base.html' %}

{% block content %}
<div class="row"><h2>Select Policy from the list:</h2>
    <form method="POST">
        <div class="table-responsive">
            <table id="myTable" class="table table-striped table-hover ">
                <thead>
                <tr id="myHeader">
                    <th>Check</th>
                    <th>Id</th>
                    <th>Policy name</th>
                    <th>Description</th>
                </tr>
                </thead>
                <tbody>
                {% for row in data %}
                <tr>
                    <td><input type="radio" value="{{row[0]}}" name="check"></td>
                    <td>{{row[0]}}</td>
                    <td>{{row[1]}}</td>
                    <td>{{row[2]}}</td>
                </tr>
                {% endfor %}
                </tbody>
            </table>
        </div>
        <div class="row">
            <input type="hidden" name="id" value="-1">
            <div class="row">
                <input class="btn btn-lg btn-primary" type="submit" value="OK">
            </div>
        </div>
    </form>
</div>
{% endblock %}