{% extends 'base.html' %}
{% block content %}
<div class="card">
    <div class="card-header">
        {{header}}
    </div>
    <div class="card-body">
        <h5 class="card-title">{{title}}</h5>
        <p class="card-text">{{text|safe}}</p>
    </div>
    <div class="card-footer text-muted">
    </div>
</div>
{% endblock %}